django-filter — django-filter 0.9.0 documentation

### Navigation

- index
- next |
- django-filter 0.9.0 documentation »

# django-filter

Django-filter is a generic, reusable application to alleviate writing some of the more mundane bits of view code. Specifically, it allows users to filter down a queryset based on a model’s fields, displaying the form to let them do this.

Contents:

- Installing django-filter
- Using django-filter
- Filter Reference
- Widget Reference
- Running the django-filter tests

### Navigation

- index
- next |
- django-filter 0.9.0 documentation »